@@ -19,7 +19,12 @@ try:
 except ImportError:
     SKIP_DRF_TESTS = True
 
-from permafrost.models import PermafrostRole, get_current_site
+from permafrost.models import (
+    PermafrostRole,
+    get_current_site,
+    CATEGORIES,
+    get_all_perms_for_all_categories
+)
 
 
 class PermafrostRoleModelTest(TestCase):
@@ -258,6 +263,21 @@ class PermafrostRoleModelTest(TestCase):
         with self.assertRaises(Group.DoesNotExist):
             group = Group.objects.get(name=group_name)
 
+    def test_get_all_perms_for_all_categories(self):
+        all_perm_names = [perm.name for perm in get_all_perms_for_all_categories()]
+
+        # grab all the names from CATEGORIES in settings
+        category_perm_names = []
+        for category, category_data in CATEGORIES.items():
+            for optional_perm_data in category_data['optional']:
+                category_perm_names.append(optional_perm_data['label'])
+
+            for optional_perm_data in category_data['required']:
+                category_perm_names.append(optional_perm_data['label'])
+
+        self.assertListEqual(sorted(all_perm_names), sorted(category_perm_names))
+
+
 
 # Don't run the following tests if DRF is not loaded
 @skipIf(SKIP_DRF_TESTS, "Django Rest Framework not installed, skipping tests")
