@@ -10,6 +10,8 @@ urlpatterns = [
     path("role/create/", views.PermafrostRoleCreateView.as_view(), name="role-create"),
     path("role/<slug:slug>/", views.PermafrostRoleDetailView.as_view(), name="role-detail"),
     path("role/<slug:slug>/update/", views.PermafrostRoleUpdateView.as_view(), name="role-update"),
+    path("role/<slug:slug>/permissions/add", views.PermafrostCustomRoleModalView.as_view(), name="custom-role-add-permissions"),
+    path("role/<slug:slug>/permissions/search", views.update_permission_table, name="custom-role-search-permissions"),
 ]
 
 
